==> autoscaling-1.60.0-sources.jar: software/amazon/awscdk/services/autoscaling/HealthCheck.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * Health check settings.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.648Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.HealthCheck")
public class HealthCheck extends software.amazon.jsii.JsiiObject {

    protected HealthCheck(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected HealthCheck(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Use EC2 for health checks.
     * <p>
     * @param options EC2 health check options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.HealthCheck ec2(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.autoscaling.Ec2HealthCheckOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.autoscaling.HealthCheck.class, "ec2", software.amazon.awscdk.services.autoscaling.HealthCheck.class, new Object[] { options });
    }

    /**
     * Use EC2 for health checks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.HealthCheck ec2() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.autoscaling.HealthCheck.class, "ec2", software.amazon.awscdk.services.autoscaling.HealthCheck.class);
    }

    /**
     * Use ELB for health checks.
     * <p>
     * It considers the instance unhealthy if it fails either the EC2 status checks or the load balancer health checks.
     * <p>
     * @param options ELB health check options. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.HealthCheck elb(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.ElbHealthCheckOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.autoscaling.HealthCheck.class, "elb", software.amazon.awscdk.services.autoscaling.HealthCheck.class, new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getType() {
        return this.jsiiGet("type", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getGracePeriod() {
        return this.jsiiGet("gracePeriod", software.amazon.awscdk.core.Duration.class);
    }
}

==> autoscaling-1.93.0-sources.jar: software/amazon/awscdk/services/autoscaling/HealthCheck.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * Health check settings.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:04.989Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.HealthCheck")
public class HealthCheck extends software.amazon.jsii.JsiiObject {

    protected HealthCheck(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected HealthCheck(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Use EC2 for health checks.
     * <p>
     * @param options EC2 health check options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.HealthCheck ec2(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.autoscaling.Ec2HealthCheckOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.autoscaling.HealthCheck.class, "ec2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.HealthCheck.class), new Object[] { options });
    }

    /**
     * Use EC2 for health checks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.HealthCheck ec2() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.autoscaling.HealthCheck.class, "ec2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.HealthCheck.class));
    }

    /**
     * Use ELB for health checks.
     * <p>
     * It considers the instance unhealthy if it fails either the EC2 status checks or the load balancer health checks.
     * <p>
     * @param options ELB health check options. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.HealthCheck elb(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.ElbHealthCheckOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.autoscaling.HealthCheck.class, "elb", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.HealthCheck.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getType() {
        return software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getGracePeriod() {
        return software.amazon.jsii.Kernel.get(this, "gracePeriod", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
    }
}
